@@ -2,11 +2,11 @@
 ## Classical optimal IC (optimal in sense of the Cramer-Rao bound)
 ###############################################################################
 setMethod("optIC", signature(model = "L2ParamFamily", risk = "asCov"),
-    function(model, risk, withMakeIC = FALSE){
-        Curve <- as((trafo(model@param) %*% solve(model@FisherInfo)) %*% model@L2deriv, "EuclRandVariable")
-        asCov <- trafo(model@param) %*% solve(model@FisherInfo) %*% t(trafo(model@param))
+    function(model, risk, withMakeIC = FALSE, ...){
+        Curve <- as((trafo(model@param) %*% distr::solve(model@FisherInfo)) %*% model@L2deriv, "EuclRandVariable")
+        asCov <- trafo(model@param) %*% distr::solve(model@FisherInfo) %*% t(trafo(model@param))
 
-        modifyIC <- function(L2Fam, IC){ optIC(L2Fam, asCov()) }
+        modifyIC <- function(L2Fam, IC, withMakeIC=FALSE, ...){ optIC(L2Fam, asCov()) }
         L2call <- model@fam.call
         L2call$trafo <- trafo(model)
         IC.o <- IC(
@@ -17,6 +17,6 @@ setMethod("optIC", signature(model = "L2ParamFamily", risk = "asCov"),
             Risks = list(asCov = asCov, trAsCov = sum(diag(asCov))),
             Infos = matrix(c("optIC", "optimal IC in sense of Cramer-Rao bound"), 
                         ncol = 2, dimnames = list(character(0), c("method", "message"))))
-        if(withMakeIC) IC.o <- makeIC(IC.o,model)
+        if(withMakeIC) IC.o <- makeIC(IC.o,model, ...)
         return(IC.o)
     })
